=======
History
=======

0.1.0 (2023-01-18)
------------------

* First added to github
* First added to pypi


0.1.1 (2023-01-21)
------------------

* Passing build on readthedocs

0.1.2 (TBA)

* Add usage documentation
* Add docstrings on all functions (pass pydocstyle audit)


0.2.0 (TBA)
-----------

* Include iteration through search results
* Include async requests


0.3.0 (TBA)
-----------

* Add github actions for automatic testing


1.0.0 (TBA)
-----------

